Presentation — Stéganô 0.8.1 documentation

# Presentation

Stéganô is a pure Python steganography module.

Steganography is the art and science of writing hidden messages in such a way that no one, apart from the sender and intended recipient, suspects the existence of the message, a form of security through obscurity. Consequently, functions provided by Stéganô only hide messages, without encryption. Steganography is often used with cryptography.

Stéganô implements these methods of hiding:

- using the red portion of a pixel to hide ASCII messages;
- using the Least Significant Bit (LSB) technique;
- using the LSB technique with sets based on generators (Sieve for Eratosthenes, Fermat, Mersenne numbers, etc.);
- using the description field of the image (JPEG and TIFF).

Moreover some methods of steganalysis are provided:

- steganalysis of LSB encoding in color images;
- statistical steganalysis.

# Requirements

- Python 3;
- Pillow;
- piexif.

# Turorial

- Installation
- Using Stéganô as a Python module
  - LSB method
  - LSB method with sets
  - Description field of the image
- Using Stéganô in command line
  - The command `stegano-lsb`
  - The command `stegano-lsb-set`
  - The command `stegano-red`
- Steganalysis
  - Parity

You can also have a look at the unit tests.

# License

Stéganô is under GPL v3 license.

# Donation

If you wish and if you like Stéganô, you can donate via bitcoin. My bitcoin address: 1GVmhR9fbBeEh7rP1qNq76jWArDdDQ3otZ

# Contact

My home page